.. hermes-simulator

:Name: Hermes Simulator
:Website: https://poliastro.github.io/
:Author: Jos van 't Hof
:Version: 0.1-beta

.. |docs| image:: https://img.shields.io/badge/docs-latest-brightgreen.svg?style=flat-square
   :target: https://docs.poliastro.space/en/latest/?badge=latest

.. |license| image:: https://img.shields.io/github/license/josvth/hermes-simulator   :alt: GitHub

.. |astropy| image:: http://img.shields.io/badge/powered%20by-AstroPy-orange.svg?style=flat-square
   :target: http://www.astropy.org/

|docs| |license| |astropy|

< Some description >

.. code-block:: python

    from hermes.examples import O3b_example

    O3b_example()


Installation
============

The easiest and fastest way to get the package up and running is to
install the hermes simulator is using `conda <http://conda.io>`_::

  $ conda install poliastro --channel conda-forge

Please check out the `documentation for alternative installation methods`_.

.. _`documentation for alternative installation methods`: https://docs.poliastro.space/en/latest/getting_started.html#alternative-installation-methods
